@@ -1,6 +1,5 @@
-from typing import Optional, List
-
 from vkbottle_types.responses import notifications
+from typing import Optional, Any, List
 from .base_category import BaseCategory
 
 
@@ -18,22 +17,22 @@ class NotificationsCategory(BaseCategory):
         :param count: Number of notifications to return.
         :param start_from:
         :param filters: Type of notifications to return: 'wall' — wall posts, 'mentions' — mentions in wall posts, comments, or topics, 'comments' — comments to wall posts, photos, and videos, 'likes' — likes, 'reposted' — wall posts that are copied from the current user's wall, 'followers' — new followers, 'friends' — accepted friend requests
-        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a notification to return. By default, 24 hours ago.
-        :param end_time: Latest timestamp (in Unix time, **kwargs) of a notification to return. By default, the current time.
+        :param start_time: Earliest timestamp (in Unix time) of a notification to return. By default, 24 hours ago.
+        :param end_time: Latest timestamp (in Unix time) of a notification to return. By default, the current time.
         """
 
         params = self.get_set_params(locals())
-        return notifications.GetResponse(
-            **await self.api.request("notifications.get", params)
-        ).response
+        response = await self.api.request("notifications.get", params)
+        model = notifications.GetResponse
+        return model(**response).response
 
     async def mark_as_viewed(self, **kwargs) -> notifications.MarkAsViewedResponseModel:
         """Resets the counter of new notifications about other users' feedback to the current user's wall posts."""
 
         params = self.get_set_params(locals())
-        return notifications.MarkAsViewedResponse(
-            **await self.api.request("notifications.markAsViewed", params)
-        ).response
+        response = await self.api.request("notifications.markAsViewed", params)
+        model = notifications.MarkAsViewedResponse
+        return model(**response).response
 
     async def send_message(
         self,
@@ -53,6 +52,6 @@ class NotificationsCategory(BaseCategory):
         """
 
         params = self.get_set_params(locals())
-        return notifications.SendMessageResponse(
-            **await self.api.request("notifications.sendMessage", params)
-        ).response
+        response = await self.api.request("notifications.sendMessage", params)
+        model = notifications.SendMessageResponse
+        return model(**response).response
